`timescale 1ns/1ps

module iirhpsimu;
reg nd, firclock, firreset;
reg signed [62:0] x;
reg signed [64:0] dither; // more bits than required, superfluous bits won't be connected
reg [1:0] freqsel;
wire signed [26:0] y;
wire rdy;

integer Jaap;
integer Piet;

iirhp iir(y, rdy, x, nd, dither, freqsel, firclock, firreset);
// Stereo IIR high-pass, processes left sample, right sample, left sample and
// so on.
// freqsel = 2'b00: integrators frozen, 0 Hz cut-off
// freqsel = 2'b01: 1.211668 Hz cut-off at 88.2 kHz sample rate
// freqsel = 2'b10: 4.846672 Hz cut-off at 88.2 kHz sample rate
// freqsel = 2'b11: 9.693344 Hz cut-off at 88.2 kHz sample rate
// In all cases, the response is close to second-order Butterworth.


initial
begin
	freqsel = 2'b11;
	Jaap = 0;
	dither = 65'b0;
	firreset = 1'b1;
	firclock = 1'b0;
	nd = 1'b1;
	x = 63'sb011111111111111111111111111111111111111111111111111111111111111;
	Piet = $fopen("iiruit.txt");
	for (Jaap = 1; Jaap < 350001; Jaap = Jaap + 1)
	begin
		#140 firclock = ~firclock; // seriously underclocked to speed up the simulation
		if (Jaap % 20 == 0)
		begin
			if (Jaap > 30) x = 63'sb0;
			nd = 1'b1;
		end
		else
			nd = 1'b0;
		#140 firclock = ~firclock;
		if (rdy) $fdisplay(Piet, Jaap," y: ",y);
	end
	$fflush;
	$fclose(Piet);
	$finish;
end
initial #450 firreset = 1'b0;
initial #730 nd = 1'b0;
endmodule
